@@ -127,6 +127,18 @@ pub fn logo(os_id: &str) -> (Vec<&str>, Color) {
                 .collect(),
             Color::Green,
         ),
+        "freebsd" => (
+            r#"
+          
+-.,____,.-
+\/    ', /
+|       `|
+`,      ,'
+  `----`  "#
+                .split('\n')
+                .collect(),
+            Color::Red,
+        ),
         "Android" => (
             r#"
           
@@ -137,7 +149,7 @@ pub fn logo(os_id: &str) -> (Vec<&str>, Color) {
                 .collect(),
             Color::Green,
         ),
-        "Windows" | "Windows 10 Home" => (
+        "Windows" => (
             r#"
           
   ... ... 
@@ -157,7 +169,7 @@ pub fn logo(os_id: &str) -> (Vec<&str>, Color) {
   ####### "#
                 .split('\n')
                 .collect(),
-            Color::White,
+            Color::Yellow,
         ),
     }
 }
